<?php

/**
 * Implementation of hook_drush_command().
 */
function inkribbon_drush_command() {
  $items = array();

  $items['inkribbon'] = array(
    'description' => 'Set up an Ink Ribbon starter kit.',
    'arguments' => array(
      'name' => 'A name for your theme.',
      'machine_name' => '[optional] A machine-readable name for your theme.',
    ),
    'examples' => array(
      'drush ink "My theme"',
    ),
    'aliases' => array('ink'),
  );

  return $items;
}

/**
 * Command: set up an Ink Ribbon starter kit.
 */
function drush_inkribbon($name = 'My theme', $machine_name = '') {
  $machine_name = ($machine_name) ? $machine_name : preg_replace('/[^a-z0-9]+/', '', strtolower($name));
  $inkribbon_path = drush_locate_root() . '/' . drupal_get_path('theme', 'inkribbon');

  $subtheme_path = split('/', $inkribbon_path);
  array_pop($subtheme_path);
  $subtheme_path = join('/', $subtheme_path) . '/' . $machine_name;

  // Make a fresh copy of the starter kit and rename things where applicable.
  drush_op('inkribbon_copy', $inkribbon_path . '/STARTERKIT', $subtheme_path, '/^(\.(\.)?|CVS|SVN|\.DS_Store)$/');
  drush_op('inkribbon_file_str_replace', $subtheme_path . '/STARTERKIT.info.txt', 'name = STARTERKIT', 'name = ' . $name);
  drush_op('rename', $subtheme_path . '/STARTERKIT.info.txt', $subtheme_path . '/' . $machine_name . '.info');

  // Notify user of the newly created theme.
  drush_print(dt('Starter kit for !name created in !path.',
    array(
      '!name' => $name,
      '!path' => $subtheme_path,
    )));
}

/**
 * Copy a directory recursively.
 */
function inkribbon_copy($source_dir, $target_dir, $ignore = '/^\.(\.)?$/') {
  if (!is_dir($source_dir)) {
    drush_die(dt('The directory !directory was not found.', array('!directory' => $source_dir)));
  }
  $dir = opendir($source_dir);
  @mkdir($target_dir);
  while($file = readdir($dir)) {
    if (!preg_match($ignore, $file)) {
      if (is_dir($source_dir . '/' . $file)) {
        inkribbon_copy($source_dir . '/' . $file, $target_dir . '/' . $file, $ignore);
      }
      else {
        copy($source_dir . '/' . $file, $target_dir . '/' . $file);
      }
    }
  }
  closedir($dir);
}

/**
 * Replace strings in file contents.
 */
function inkribbon_file_str_replace($file_path, $find, $replace) {
  $file_contents = file_get_contents($file_path);
  $file_contents = str_replace($find, $replace, $file_contents);
  file_put_contents($file_path, $file_contents);
}
